@@ -8,7 +8,7 @@ impl Application {
 }
 
 impl wita::EventHandler for Application {
-    fn closed(&mut self, _: &wita::Window) {
+    fn closed(&mut self, _: wita::event::Closed) {
         println!("closed");
     }
 }
