@@ -39,10 +39,7 @@ fn load_icon_impl(hinst: HINSTANCE, icon: &Icon, cx: i32, cy: i32) -> HICON {
             ),
         }
     };
-    if icon == HANDLE(0) {
-        panic!("cannot load the icon");
-    }
-    HICON(icon.0)
+    HICON(icon.unwrap().0)
 }
 
 pub(crate) fn load_icon(icon: &Icon, hinst: HINSTANCE) -> HICON {
